.. _funding:

=======
Funding
=======

aeon is a community-driven project, however institutional and private
grants help to assure its sustainability.

If you would like to sponsor aeon, please visit our `page <https://opencollective.com/aeon>`_ on Open Collective.

We would like to thank the following sponsors.

Industry sponsorship
--------------------

* Mercedes-Benz AG/Daimler AG donated 2500 EUR to support the maintenance and development of sktime in 2021, as part of their `FOSS program <https://opensource.mercedes-benz.com>`_.

Research grants
---------------

`The Alan Turing Institute <https://turing.ac.uk>`__ funded three months
of the initial development under the UKRI Strategic Priorities Fund
(EPSRC grant no EP/T001569/1), particularly the `Tools, Practices and
Systems <https://www.turing.ac.uk/events/tools-practices-and-systems-data-science-and-artificial-intelligence-scoping-workshop>`__
theme within that grant.

Markus Löning’s contributions between 2019 and 2021 were supported by:

* the `UK Economic and Social Research Council (ESRC) <https://esrc.ukri.org>`_,
* the `Consumer Data Research Centre (CDRC) <https://www.cdrc.ac.uk>`_,
* the Enrichment Scheme at the `The Alan Turing Institute <https://turing.ac.uk>`_,
* the JROST Rapid Response Fund, a community effort of `Invest in Open Infrastructure <https://investinopen.org>`_.

.. image:: ../images/the-alan-turing-institute.png
  :width: 32 %
  :target: https://turing.ac.uk/

.. image:: ../images/esrc-ukri.png
  :width: 32 %
  :target: https://esrc.ukri.org

.. image:: ../images/cdrc.jpg
  :width: 32 %
  :target: https://www.cdrc.ac.uk

Institutional sponsorship
-------------------------

The 2019 joint sktime MLJ development sprint was kindly hosted by `UCL <https://www.ucl.ac.uk>`_ and `The Alan Turing Institute <https://turing.ac.uk>`_. Some participants could attend thanks to the initial funding of the `The Alan Turing Institute <https://turing.ac.uk>`_.

Since 2022, `sktime` is an officially affiliated project of the `NumFOCUS <https://numfocus.org/>`_ organization.

.. image:: ../images/numfocus.png
  :width: 32 %
  :target: https://numfocus.org

Infrastructure
--------------

We would also like to thank `Microsoft
Azure <https://azure.microsoft.com/en-gb/services/devops/>`__, `GitHub
Actions <https://docs.github.com/en/free-pro-team@latest/actions>`__,
`AppVeyor <https://www.appveyor.com>`__ and
`ReadtheDocs <https://readthedocs.org>`__ for the free compute time on
their servers.

Internships
-----------

`Google Summer of Code (GSoC) <https://summerofcode.withgoogle.com>`_, `Major League Hacking <https://mlh.io>`_ and `Outreachy <https://www.outreachy.org>`_ have all sponsored sktime internships.

The `Wellcome Trust <https://wellcome.org>`_ sponsored one sktime internship as part of Outreachy.

.. image:: ../images/gsoc.png
  :width: 32 %
  :target: https://summerofcode.withgoogle.com


.. list-table::
   :header-rows: 1

   * - Name
     - GitHub ID
     - Organization
     - Year
   * - Katie Buchhorn
     - :user:`KatieBuc`
     - Google Summer of Code
     - 2022
   * - Mirae Parker
     - :user:`miraep8`
     - Google Summer of Code
     - 2022
   * - Shivansh Subramanian
     - :user:`AurumnPegasus`
     - Google Summer of Code
     - 2022
   * - Guzal Bulatova
     - :user:`GuzalBulatova`
     - Outreachy
     - 2021
   * - Svea Marie Meyer
     - :user:`SveaMeyer13`
     - Google Summer of Code via `INCF <https://www.incf.org>`_
     - 2021
